CREATE OR REPLACE
PACKAGE BODY          "GESTION_LOCALITAT" AS
  c_procesLog	   LOG_TFC.procesLog%TYPE;	
  c_dataHoraLog    LOG_TFC.dataHoraLog%TYPE;
  c_entradaLog     LOG_TFC.entradaLog%TYPE;	
  c_sortidaLog     LOG_TFC.sortidaLog%TYPE;
  s_rsp	           LOG_TFC.rspLog%TYPE; 
  n_registres  NUMBER;
  n_idLocalitat LOCALITAT.IDLOCALITAT%TYPE;
  n_descripcioLocalitat LOCALITAT.DESCRIPCIOLOCALITAT%TYPE;
  n_descripcioProvincia PROVINCIA.DESCRIPCIOPROVINCIA%TYPE;
  n_descripcioPais PAIS.DESCRIPCIOPAIS%TYPE;
  
  s_sql VARCHAR2 (2000);
  n_descripcioLocalitat LOCALITAT.DESCRIPCIOLOCALITAT%TYPE;
  n_idpProvinciaLocalitat LOCALITAT.IDPROVINCIALOCALITAT%TYPE;
  
  n_NUM_ERR NUMBER(10);
  sortida varchar2(500):=''; 
  e_localitat    EXCEPTION;
  --------------------------------------------------------------
-- create procedure for table "LOG_TFC i LOCALITAT"

/******************************************************************************
Autor: Eduard Monzonis Hierro                                   UOC
18/05/2012                                             TFC: CONTROL ENERGIA.
                PROCEDIMENT ALTA DE LOCALITAT
DESCRIPCIO:
Procediment per gestionar les localitats on estan geograficamnt el COMPTADORS,
CENTRALS, CLIENTS, FABRICANTS. Totes aquelles entitats que necessiten per 
motius de negoci esta ubicades en un lloc físic.
D'aquest procediement depent PROVINCIa  i PA?S, que l'entitat UBICACIO hereda
dades d'aquesta entitat per poder gestionar les dirección de les entitats
que precisen esta ubicades de forma física per motius del negoci qe el sistema
en el rojecte precisa.
******************************************************************************/
PROCEDURE PRC_ALTA_LOCALITAT(
    p_descripcioLocalitat in LOCALITAT.DESCRIPCIOLOCALITAT%TYPE,
    p_idProvinciaLocalitat in LOCALITAT.IDPROVINCIALOCALITAT%TYPE,
    s_rsp out NOCOPY VARCHAR2)
    AS
    
    BEGIN
    c_procesLog :='PRC_ALTA_LOCALITAT';
    c_dataHoraLog := SYSDATE;
    c_entradaLog := 'Decripcio LOCALITAT: '|| p_descripcioLocalitat ||
                  ', Codi de Provincia: '|| p_idProvinciaLocalitat;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('    ALTA LOCALITAT    ');
    DBMS_OUTPUT.PUT_LINE('______________________');
    DBMS_OUTPUT.PUT_LINE('Decripcio LOCALITAT: '|| p_descripcioLocalitat ||
                  ', Codi de Provincia: '|| p_idProvinciaLocalitat);
    c_sortidalog := 's_rsp'; 
 
  If (p_descripcioLocalitat IS NULL) OR (p_idProvinciaLocalitat IS NULL ) then
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' ALTA LOCALITAT: '); 
      s_rsp := 'Falta especificar la localitat i el codi de Provincia ';
      DBMS_OUTPUT.PUT_LINE(s_rsp);
      RAISE  e_localitat;
  END IF;
     -- Comprovem si existeix  la localitat a  donar d'alta
  SELECT COUNT (*)INTO n_registres 
    FROM LOCALITAT
  WHERE DESCRIPCIOLOCALITAT = p_descripcioLocalitat;
  If n_registres=0 then
    -- El donem d'alta a la Via Publica          
  INSERT INTO LOCALITAT(LOCALITAT.DESCRIPCIOLOCALITAT,
    LOCALITAT.IDPROVINCIALOCALITAT) 
  VALUES(p_descripcioLocalitat,p_idProvinciaLocalitat);
--Gravem en la taula log-----------------------------------------------------
   DBMS_OUTPUT.ENABLE;
   DBMS_OUTPUT.PUT_LINE('Insertada la Localitat: '||p_descripcioLocalitat||
        ' amb el codi de Provincia: ' ||p_idProvinciaLocalitat);
   DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
   s_rsp :='Ok: Insertada la Localitat: '||p_descripcioLocalitat||
        ' amb el codi de Provincia: ' ||p_idProvinciaLocalitat;
   pkg_general.gravar_log_procedure(c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
   DBMS_OUTPUT.PUT_LINE(s_rsp);
  ELSE
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('ALTA LOCALITAT: ');
    s_rsp := 'Dades de la Localitat duplicades.  ';
    DBMS_OUTPUT.PUT_LINE(s_rsp);
    RAISE e_localitat;
  END IF;
COMMIT;

   EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('ALTA_LOCALITAT: '); 
            DBMS_OUTPUT.put_line(s_rsp);
            pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;
END PRC_ALTA_LOCALITAT;

/********************************************************************************
Autor: Eduard Monzonis Hierro                                   UOC
18/05/2012                                             TFC: CONTROL ENERGIA.
                    PROCEDURE MODIFICAR LOCALITAT
DESCRIPCIO:
Procediment per gestionar les modificacions de l'entitat.
********************************************************************************/
PROCEDURE PRC_MODIFICAR_LOCALITAT(
    p_idLocalitat in LOCALITAT.IDLOCALITAT%TYPE,
    p_descripcioLocalitat in LOCALITAT.DESCRIPCIOLOCALITAT%TYPE,
    p_idProvinciaLocalitat in LOCALITAT.IDPROVINCIALOCALITAT%TYPE,
    s_rsp out NOCOPY VARCHAR2)
    AS
    
    BEGIN
    c_procesLog := 'PRC_MODIFICAR_LOCALITAT';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :=' Codi Localitat: ' || p_idLocalitat||
                    ', Descripcio Localitat: ' || p_descripcioLocalitat||
                    ', Codi Provincia: ' ||p_idProvinciaLocalitat;
   DBMS_OUTPUT.PUT_LINE(' ');
   DBMS_OUTPUT.PUT_LINE('  MODIFICAR UNA LOCALITAT   ');
   DBMS_OUTPUT.PUT_LINE('____________________________');
   DBMS_OUTPUT.PUT_LINE(' Codi Localitat: ' || p_idLocalitat||
                    ', Descripcio Localitat: ' || p_descripcioLocalitat||
                    ', Codi Provincia: ' ||p_idProvinciaLocalitat);
    c_sortidalog := 's_rsp';
    -- Comprovació del identificador Localitat-----
  IF p_idLocalitat IS NULL OR p_idLocalitat=0 THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('MODIFICAR UNA LOCALITAT: '); 
    s_rsp := 'Falta especificar  el codi Localitat';
    DBMS_OUTPUT.put_line(s_rsp);        
    RAISE e_localitat;
  END IF;
  If p_descripcioLocalitat IS NULL THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('MODIFICAR UNA LOCALITAT: ');         
    s_rsp := 'Falta especificar Localitat';
    DBMS_OUTPUT.put_line(s_rsp);           
    RAISE e_localitat;
  END IF;
  If p_idProvinciaLocalitat IS NULL OR p_idProvinciaLocalitat=0 THEN
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('ODIFICAR UNA LOCALITAT: ');       
      s_rsp := 'Falta especificar codi de la Provincia de la Localitat';
      DBMS_OUTPUT.put_line(s_rsp);              
      RAISE e_localitat;
   END IF;
  -- MIREM SI ESTA DONAT ALTA
  SELECT COUNT (*)INTO n_registres 
  FROM LOCALITAT 
  WHERE LOCALITAT.IDLOCALITAT =p_idLocalitat;
  
  If n_registres=0 then
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('MODIFICAR UNA LOCALITAT: ');          
    s_rsp := 'LOCALITAT no existeix a la BBDD';
    DBMS_OUTPUT.PUT_LINE(s_rsp);
    RAISE e_localitat;
  END IF;
-- recuperem el codi de la Localitat
  SELECT LOCALITAT.IDLOCALITAT INTO n_idLocalitat
  FROM LOCALITAT
  WHERE IDLOCALITAT = p_idLocalitat;
    
         
  s_sql := 'UPDATE LOCALITAT SET ';
             
-- Construirem la sentencia UPDATE segons si hi ha valor en els paràmetres-
  IF  p_descripcioLocalitat IS NOT NULL  THEN
-- Modifiquem el codi Localitat
   s_sql := s_sql || 'DESCRIPCIOLOCALITAT=''' ||p_descripcioLocalitat|| ''','; 
  END IF;
  IF p_idProvinciaLocalitat IS NOT NULL  THEN
-- Modifiquem CODI PROVINCIA
    s_sql := s_sql || 'IDPROVINCIALOCALITAT=''' ||p_idProvinciaLocalitat|| ''',';
  END IF;               
-- Eliminem la coma final de la sentencia SQL
  s_sql := SUBSTR (s_sql, 1, LENGTH (s_sql) - 1);
  -- Afegim a la sentencia la condició del WHERE
  s_sql := s_sql || ' WHERE IDLOCALITAT''' ||n_idLocalitat|| '''';
              
  EXECUTE IMMEDIATE s_sql;
      
  IF SQL%ROWCOUNT = 0  THEN
--L'error serà que el la via ja el tenim en la taula i no admet duplicats--
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('MODIFICAR UNA LOCALITAT: ');                    
    s_rsp := 'Actualitzacio no realitzada';
    DBMS_OUTPUT.PUT_LINE(s_rsp);  
    RAISE e_localitat;
  ELSE
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('Modificacio de la Localitat
      feta satisfactoriament : codi Localitat: '||n_idLocalitat||
                 ' Descripcio: ' ||p_descripcioLocalitat||
                 ' codi del Provincia: '||p_idProvinciaLocalitat);
    DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
    pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  END IF;
COMMIT;
EXCEPTION
   WHEN DUP_VAL_ON_INDEX THEN
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('MODIFICAR UNA LOCALITAT: ');     
      s_rsp := 'Error: Localitat duplicada. No es poden fer les modificacions';
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;      
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || SQLCODE || SUBSTR(SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' ');  
      DBMS_OUTPUT.put_line (s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;  
  END PRC_MODIFICAR_LOCALITAT;
/*******************************************************************************  
 Autor: Eduard Monzonis Hierro                                   UOC
18/05/2012                                             TFC: CONTROL ENERGIA.
                   CONSULTA DE LES LOCALITATS
DESCRIPCIO:
Procediment per consultar una Localitat i que per herencia i integritat
referencial en cascade obtenim PROVINCIA i PAIS de la LOCALITAT.
*******************************************************************************/
PROCEDURE PRC_CONSULTA_UNA_LOCALITAT(
    p_descripcioLocalitat in LOCALITAT.DESCRIPCIOLOCALITAT%TYPE,
    s_rsp out NOCOPY VARCHAR2)
  AS
  n_idLocalitat LOCALITAT.IDLOCALITAT%TYPE;
  n_descripcioLocalitat LOCALITAT.DESCRIPCIOLOCALITAT%TYPE;
  n_descripcioProvincia PROVINCIA.DESCRIPCIOPROVINCIA%TYPE;
  n_descripcioPais PAIS.DESCRIPCIOPAIS%TYPE;
  BEGIN
   c_procesLog := 'PRC_CONSULTA_UNA_LOCALITAT';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :=' Descripcio Localitat: ' || p_descripcioLocalitat;
   DBMS_OUTPUT.PUT_LINE(' ');
   DBMS_OUTPUT.PUT_LINE('  CONSULTA UNA LOCALITAT    ');
   DBMS_OUTPUT.PUT_LINE('____________________________');
   DBMS_OUTPUT.PUT_LINE(' Descripcio Localitat: ' || p_descripcioLocalitat);
-- Comprovem que  p_descripcioLocalitat no sigui NULL----------------------------------------------
 If  p_descripcioLocalitat IS NULL then
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('CONSULTA UNA LOCALITAT: ');       
  s_rsp := 'Falta especificar LOCALITAT';
  DBMS_OUTPUT.put_line (s_rsp);           
  RAISE e_localitat;
 END IF;
--1er. Comprovem que existeixi la persona-------------------------------
  SELECT COUNT (*) INTO n_registres 
  FROM LOCALITAT
  WHERE LOCALITAT.DESCRIPCIOLOCALITAT= p_descripcioLocalitat;
  
  If n_registres=0 then
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('CONSULTA UNA LOCALITAT: ');              
    s_rsp := 'LOCALITAT no existent a la BBDD';
    DBMS_OUTPUT.PUT_LINE(s_rsp);
    RAISE e_localitat;
  END IF;
-- Recuperem les dades de la taula localitat--------------------------
  SELECT LOCALITAT.IDLOCALITAT,
         LOCALITAT.DESCRIPCIOLOCALITAT, 
         PROVINCIA.DESCRIPCIOPROVINCIA,
         PAIS.DESCRIPCIOPAIS  INTO n_idLocalitat,n_descripcioLocalitat,
         n_descripcioProvincia,n_descripcioPais
  FROM LOCALITAT,PROVINCIA,PAIS
  WHERE LOCALITAT.IDPROVINCIALOCALITAT=PROVINCIA.IDPROVINCIA 
  AND PROVINCIA.IDPAISPROVINCIA=PAIS.IDPAIS
  AND LOCALITAT.DESCRIPCIOLOCALITAT=p_descripcioLocalitat;
  
  DBMS_OUTPUT.PUT_LINE(s_sql);
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('CONSULTA UNA LOCALITAT: 
   codi Localitat: '||n_idLocalitat||
  ' Descripcio:     '||n_descripcioLocalitat||
  ' Provincia:      '||n_descripcioProvincia||
  ' Pais:           '||n_descripcioPais); 
  DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
            s_rsp := 'OK: CONSULTA UNA LOCALITAT: 
   codi Localitat: '||n_idLocalitat||
  ' Descripcio:     '||n_descripcioLocalitat||
  ' Provincia:      '||n_descripcioProvincia||
  ' Pais:           '||n_descripcioPais;
  DBMS_OUTPUT.put_line (s_rsp);
  pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);

COMMIT;
 EXCEPTION
	
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi-----------------------------------------
         s_rsp := 'Error: ' || SQLCODE || SUBSTR(SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi-----------------------------------------
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' ');   
      DBMS_OUTPUT.put_line (s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;
  
  END PRC_CONSULTA_UNA_LOCALITAT;
/*******************************************************************************  
 Autor: Eduard Monzonis Hierro                                   UOC
18/05/2012                                             TFC: CONTROL ENERGIA.
-- CONSULTA DE TOTES LES LOCALITATS AMB PROVINCIA I PAIS
******************************************************************************/
PROCEDURE PRC_CONSULTA_LOCALITATS(
    s_rsp out NOCOPY VARCHAR2)
AS
  n_idLocalitat LOCALITAT.IDLOCALITAT%TYPE;
  n_descripcioLocalitat LOCALITAT.DESCRIPCIOLOCALITAT%TYPE;
  n_descripcioProvincia PROVINCIA.DESCRIPCIOPROVINCIA%TYPE;
  n_descripcioPais PAIS.DESCRIPCIOPAIS%TYPE;

CURSOR C_LOCALITAT IS
SELECT LOCALITAT.IDLOCALITAT AS CODI,
       LOCALITAT.DESCRIPCIOLOCALITAT AS LOCALITAT, 
       PROVINCIA.DESCRIPCIOPROVINCIA AS PROVINCIA,
       PAIS.DESCRIPCIOPAIS AS PAIS
  INTO n_idLocalitat,n_descripcioLocalitat,
       n_descripcioProvincia,n_descripcioPais
FROM LOCALITAT,PROVINCIA,PAIS
WHERE LOCALITAT.IDPROVINCIALOCALITAT=PROVINCIA.IDPROVINCIA 
AND PROVINCIA.IDPAISPROVINCIA=PAIS.IDPAIS
AND LOCALITAT.IDLOCALITAT=LOCALITAT.IDLOCALITAT
ORDER BY PAIS.DESCRIPCIOPAIS,PROVINCIA.DESCRIPCIOPROVINCIA,
LOCALITAT.DESCRIPCIOLOCALITAT ;

BEGIN
    c_procesLog := 'PRC_CONSULTA_LOCALITATS';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='CONSULTA LOCALITATS ';
    c_sortidalog := 's_rsp';
    
  SELECT COUNT (*)  INTO n_registres
  FROM LOCALITAT
  WHERE LOCALITAT.IDLOCALITAT=LOCALITAT.IDLOCALITAT;
IF n_registres=0 THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('CONSULTA DE LOCALITATS: ');
    s_rsp := 'No hi han localitats donades dalta ';
    DBMS_OUTPUT.PUT_LINE(s_rsp);
    RAISE e_localitat;
 END IF;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('           CONSULTA DE LOCALITATS              ');
    DBMS_OUTPUT.PUT_LINE('-----------------------------------------------------');
  OPEN C_LOCALITAT;
   FETCH C_LOCALITAT INTO n_idLocalitat,n_descripcioLocalitat,
       n_descripcioProvincia,n_descripcioPais;
  WHILE C_LOCALITAT%FOUND LOOP
   DBMS_OUTPUT.ENABLE;
   DBMS_OUTPUT.PUT_LINE(
 ' Codi Localitat: '
 ||n_idLocalitat||
 ' Localitat: '
 ||n_descripcioLocalitat||
 ' Provincia: '
 ||n_descripcioProvincia||
 ' Pais: '
 ||n_descripcioPais);
  s_rsp := 'OK  CONSULTA LOCALITATS
  Codi Localitat: '
 ||n_idLocalitat||
 ' Descripcio:     '
 ||n_descripcioLocalitat||
 ' Provincia:      '
 ||n_descripcioProvincia||
 ' Pais:           '
 ||n_descripcioPais;
 
  FETCH C_LOCALITAT INTO n_idLocalitat,n_descripcioLocalitat,
       n_descripcioProvincia,n_descripcioPais;
  pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
 END LOOP;
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('Total localitats: '||n_registres);
  DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
CLOSE C_LOCALITAT;
COMMIT;
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi-----------------------------------------
         s_rsp := 'Error: ' || SQLCODE || SUBSTR(SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi-----------------------------------------
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' '); 
      DBMS_OUTPUT.put_line (s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;
   
END PRC_CONSULTA_LOCALITATS;    
END "GESTION_LOCALITAT";


