CREATE OR REPLACE
PACKAGE BODY          "GESTION_CLASSE_CENTRAL" AS
  c_procesLog	   LOG_TFC.procesLog%TYPE;	
  c_dataHoraLog    LOG_TFC.dataHoraLog%TYPE;
  c_entradaLog     LOG_TFC.entradaLog%TYPE;	
  c_sortidaLog     LOG_TFC.sortidaLog%TYPE;
  s_rsp	           LOG_TFC.rspLog%TYPE;
  n_registres  NUMBER;
  s_sql VARCHAR2 (2000);
  n_descripcioClasse CLASSE_CENTRAL.descripcioClasse%TYPE;
  n_idClasse   CLASSE_CENTRAL.idClasse%TYPE;
  n_NUM_ERR NUMBER(10);
  sortida varchar2(500):=''; 
  e_classe_central   EXCEPTION;

/********************************************************************************
   NOM:         PCR_ALTA_CLASSE_CENTRAL
   DESCRIPCIÓ:
                Procediment encarregat donar alta de Classe de Central. 
                La inserció de dades esta controlada per un disparador o trigger
		el qual té associat una seqúència SEQ_CLASSE_CENTRAL per generar
		la clau primaria n format numérica de forma autoincrementable 
		les dades es modificaran en la taula CENTRAL i el identificador de 
                clau primaria del de la taula Central.
********************************************************************************/ 

PROCEDURE PRC_ALTA_CLASSE_CENTRAL(
p_descripcioClasse in CLASSE_CENTRAL.descripcioClasse%TYPE,
    S_RSP OUT VARCHAR2) 
AS
BEGIN
    c_procesLog := 'PRC_ALTA_CLASSE_CENTRAL';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='Decripcio Classe de Central: ' || p_descripcioClasse;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE(' ALTA CLASSES DE CENTRALS ');
    DBMS_OUTPUT.PUT_LINE('__________________________');
    DBMS_OUTPUT.PUT_LINE('ALTA CLASSES DE CENTRALS : Decripcio Classe de Central: '
    || p_descripcioClasse); 
    c_sortidalog := 's_rsp';   
    If p_descripcioClasse IS NULL then
       DBMS_OUTPUT.ENABLE;
       DBMS_OUTPUT.PUT_LINE(' ALTA CLASSES DE CENTRALS ');       
       s_rsp := 'Falta especificar la classe de central';
       DBMS_OUTPUT.PUT_LINE(s_rsp);                 
       RAISE e_classe_central;
     END IF;
-- Comprovem si existeix el  donar d'alta
  SELECT COUNT (*) INTO n_registres 
  FROM CLASSE_CENTRAL 
  WHERE CLASSE_CENTRAL.DESCRIPCIOCLASSE=p_descripcioClasse;
  
  If n_registres=0 then
-- El donem d'alta a la Classe de Central 
      INSERT INTO CLASSE_CENTRAL(descripcioClasse) 
      VALUES(p_descripcioClasse);
 --Gravem en la taula log-----------------------------------------------------
      DBMS_OUTPUT.PUT_LINE('Insertada la classe de central: '
      ||p_descripcioClasse);
      DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
      s_rsp :='Ok: Insertat satisfactoriament'|| p_descripcioClasse;
      pkg_general.gravar_log_procedure(c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      DBMS_OUTPUT.PUT_LINE(s_rsp);
    ELSE
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('ALTA CLASSES DE CENTRALS ');
      s_rsp := 'Tipus Inspeccio duplicat ';
      DBMS_OUTPUT.PUT_LINE(s_rsp);
      RAISE e_classe_central;
    END IF;
   COMMIT;
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('  '); 
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;
end PRC_ALTA_CLASSE_CENTRAL;

/********************************************************************************
   NOM:         PRC_MODIFICA_CLASSE_CENTRAL
   DESCRIPCIÓ:
                Procediment encarregat de modificar la classe de central. 
                Controla la descripcio i el id de la classe de central.
********************************************************************************/
PROCEDURE PRC_MODIFICA_CLASSE_CENTRAL( 
      p_descripcioClasse IN CLASSE_CENTRAL.descripcioClasse%TYPE,
      P_IDCLASSE IN CLASSE_CENTRAL.idClasse%TYPE,
S_RSP OUT VARCHAR2)
as
begin
    c_procesLog := 'PRC_MODIFICAR_CALSSE_CENTRAL';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='Decripcio Central: ' || p_descripcioClasse;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('MODIFICAR CLASSES DE CENTRALS');
    DBMS_OUTPUT.PUT_LINE('______________________');
    DBMS_OUTPUT.PUT_LINE('Classe e Central: '||p_descripcioClasse);    
    c_sortidalog := 's_rsp';

-- Comprovació del identificador Classe Central
  If  (p_descripcioClasse IS NULL) THEN
     DBMS_OUTPUT.ENABLE;
     DBMS_OUTPUT.PUT_LINE('MODIFICAR CLASSES DE CENTRALS  '); 
     s_rsp := 'Falta especificar la central';
     DBMS_OUTPUT.PUT_LINE(s_rsp);
     RAISE e_classe_central;
 END IF;
     SELECT COUNT (*)INTO n_registres 
     FROM CLASSE_CENTRAL
     WHERE CLASSE_CENTRAL.DESCRIPCIOCLASSE=p_descripcioClasse;

  If n_registres=0 then
     DBMS_OUTPUT.ENABLE;
     DBMS_OUTPUT.PUT_LINE('MODIFICAR CLASSES DE CENTRALS ');           
     s_rsp := 'CLASSE_CENTRAL no existeix a la BBDD';
     DBMS_OUTPUT.PUT_LINE(s_rsp);
     RAISE e_classe_central;
  END IF;
         
-- recuperem el codi de la central
  SELECT CLASSE_CENTRAL.idClasse,
  CLASSE_CENTRAL.DESCRIPCIOCLASSE INTO n_idClasse,n_descripcioClasse
  FROM CLASSE_CENTRAL
  WHERE DESCRIPCIOCLASSE=p_descripcioClasse;
              
  s_sql := 'UPDATE CLASSE_CENTRAL SET ';
-- Construirem la sentencia UPDATE segons si hi ha valor en els paràmetres-
  IF p_descripcioClasse IS NOT NULL THEN
-- Modifiquem el descripcio classe central
     s_sql := s_sql || 'DESCRIPCIOCLASSE=''' ||p_descripcioClasse|| ''',';
  END IF;
-- Eliminem la coma final de la sentencia SQL
  s_sql := SUBSTR (s_sql, 1, LENGTH (s_sql) - 1);
-- Afegim a la sentencia la condició del WHERE
  s_sql := s_sql || ' WHERE idClasse=''' ||n_idClasse|| '''';
     
  EXECUTE IMMEDIATE s_sql;
      
  IF SQL%ROWCOUNT = 0  THEN
--L'error serà que el la via ja el tenim en la taula i no admet duplicats--
     DBMS_OUTPUT.ENABLE;
     DBMS_OUTPUT.PUT_LINE('MODIFICAR_CALSSE_CENTRAL '); 
     DBMS_OUTPUT.PUT_LINE('***********************'); 
     s_rsp := 'Actualització no realitzada';
     DBMS_OUTPUT.PUT_LINE(s_rsp);                  
     RAISE e_classe_central;
  ELSE
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('Modificacio Calsse de Central feta amb el 
      Codi Classe de Central: '||n_idClasse||
     ' Descripcio: '||p_descripcioClasse);
     DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
     DBMS_OUTPUT.put_line ('OK: Modificacio Calsse de Central feta amb el 
      Codi Classe de Central: '||n_idClasse||
     ' Descripcio: '||p_descripcioClasse);
     pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
 END IF;
COMMIT;
EXCEPTION
   WHEN DUP_VAL_ON_INDEX THEN
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('MODIFICAR CLASSE DE CENTRAL ');
      s_rsp := 'Error: Tipus Inspeccions duplicada. No es poden fer les modificacions';
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;      
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || SQLCODE || SUBSTR(SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' ');
      DBMS_OUTPUT.put_line (s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;

end PRC_MODIFICA_CLASSE_CENTRAL;
/********************************************************************************
   NOM:         PRC_CONSULTAR_CLASE_CENTRAL
   DESCRIPCIÓ:
                Procediment encarregat de consultar les dades d'una Classe de
		Central. 
            
********************************************************************************/ 
PROCEDURE PRC_CONSULTAR_CLASSE_CENTRAL(
        s_rsp out NOCOPY VARCHAR2)
AS

CURSOR C_CLASSE_CENTRAL IS
SELECT CLASSE_CENTRAL.IDCLASSE,
CLASSE_CENTRAL.DESCRIPCIOCLASSE
FROM CLASSE_CENTRAL
WHERE CLASSE_CENTRAL.IDCLASSE=CLASSE_CENTRAL.IDCLASSE;

BEGIN
    c_procesLog := 'CONSULTAR_CLASE_CENTRAL';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='CONSULTAR_CLASE_CENTRAL';
    c_sortidalog := 's_rsp';   
-- Comprovem que p_descripcioClasse  no sigui NULL----------------------------------------------
      
 --1er. Comprovem que existeixi la classe de central
    SELECT COUNT (*)      INTO n_registres    
     FROM CLASSE_CENTRAL
     WHERE  CLASSE_CENTRAL.IDCLASSE=CLASSE_CENTRAL.IDCLASSE;
     

  If n_registres=0 then
     DBMS_OUTPUT.ENABLE;
     DBMS_OUTPUT.PUT_LINE('CONSULTAR_CLASSE_CENTRAL ');             
     s_rsp := 'CLASSE CENTRAL no existent a la BBDD';
     DBMS_OUTPUT.PUT_LINE(s_rsp);
     RAISE e_classe_central;
     END IF;
     
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('           CONSULTA CLASSES DE CENTRALS          ');
    DBMS_OUTPUT.PUT_LINE('-------------------------------------------------');
    
    OPEN C_CLASSE_CENTRAL;
    FETCH C_CLASSE_CENTRAL INTO n_idClasse,n_descripcioClasse;
  WHILE C_CLASSE_CENTRAL%FOUND LOOP
   DBMS_OUTPUT.ENABLE;
   DBMS_OUTPUT.PUT_LINE(
 '   Codi Classe de Central:  '
 ||n_idClasse
 ||' Descripcio '
 ||n_descripcioClasse);
  s_rsp := 'OK  CONSULTA CLASSES DE CENTRALS 
  Codi Classe de Central:  '
 ||n_idClasse
 ||' Descripcio: '
 ||n_descripcioClasse;
  FETCH C_CLASSE_CENTRAL INTO n_idClasse,n_descripcioClasse;

  pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  
  END LOOP;
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('Total classes de centrals: '||n_registres);
  DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');

CLOSE C_CLASSE_CENTRAL;

COMMIT;
 EXCEPTION
	
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi-----------------------------------------
         s_rsp := 'Error: ' || SQLCODE || SUBSTR(SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi-----------------------------------------
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' '); 
      DBMS_OUTPUT.put_line (s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;
  
END PRC_CONSULTAR_CLASSE_CENTRAL;
END "GESTION_CLASSE_CENTRAL";
