CREATE OR REPLACE
PACKAGE BODY          "GESTION_CONECTA_CENTRALS" AS
  n_registres      NUMBER;
  s_sql           VARCHAR2 (2000);
  n_NUM_ERR 	  NUMBER(10);
 
  c_procesLog	  LOG_TFC.procesLog%TYPE;	
  c_dataHoraLog    LOG_TFC.dataHoraLog%TYPE;
  c_entradaLog     LOG_TFC.entradaLog%TYPE;	
  c_sortidaLog     LOG_TFC.sortidaLog%TYPE;
  s_rsp	 LOG_TFC.RSPLOG%TYPE; 
  
  -- VARIABLE PER OBTENIR CENTRALS DE PRODUCCIO
  n_tipusCentralProduccio NUMBER;
  -- VARIABLE PER OBTENIR CENTRALS DE DISTRIBUCIO
  n_tipusCentralDistribucio NUMBER;
  -- VARIABLE DE CONTROL CONNEXIO MÉS DE DUES CENTRALS DE DISTRIBUCIO
  -- AMB UNA DE PRODUCCIO
  n_connexio NUMBER;
  n_conectarCentral NUMBER;
  n_idConectaCentral  LINEA_CONECTA_CENTRAL.IDCONECTA%Type;
  n_estatConecta LINEA_CONECTA_CENTRAL.IDESTATC%Type;
  n_dataAltaConecta   LINEA_CONECTA_CENTRAL.DATAALTAC%Type;
  n_conectaCentralProduccio   LINEA_CONECTA_CENTRAL.CONNECTACPRODU%TYPE;
  n_conectaCentralDistribucio  LINEA_CONECTA_CENTRAL.CONNECTACDISTRI%TYPE;
  n_dataModificacioConecta LINEA_CONECTA_CENTRAL.DATAMODIFICACIOC%TYPE;
  n_observacions LINEA_CONECTA_CENTRAL.OBSERVACIOC%TYPE;
  
  n_controlEstatPro ESTAT.IDESTAT%TYPE;
  n_produccio NUMBER;
  n_controlEstatDis ESTAT.IDESTAT%TYPE;
  n_distribucio NUMBER;
  n_descEstatConecta ESTAT.DESCRIPCIOESTAT%TYPE;
  n_lineaProduccio NUMBER;
  n_lineaDistribucio NUMBER;
  
  sortida VARCHAR2(1000):='';
  e_conceta_centrals   EXCEPTION;
--------------------------------------------------------------
/******************************************************************************
        NOM: PRC_CONECTA_CENTRALS
        DESCRIPCIO: procediment per conectar una central de Produccio amb
        una o dues de Distribucio.
******************************************************************************/
PROCEDURE PRC_CONECTA_CENTRALS(
    p_dataAltaConecta in LINEA_CONECTA_CENTRAL.DATAALTAC%Type,
    p_conectaCentralProduccio in LINEA_CONECTA_CENTRAL.CONNECTACPRODU%Type,
    p_conectaCentralDistribucio in LINEA_CONECTA_CENTRAL.CONNECTACDISTRI%Type,
    p_observacionsConecta in LINEA_CONECTA_CENTRAL.OBSERVACIOC%Type,
    s_rsp out NOCOPY VARCHAR)
AS
BEGIN
    c_procesLog := 'PRC_CONECTA_CENTRALS';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :=' Data Alta: ' ||p_dataAltaConecta||
    ', Codi Central Produccio: ' ||p_conectaCentralProduccio||
    ', Codi Central Distribucio: ' ||p_conectaCentralDistribucio||
    ', Observacions Connexio: ' ||p_observacionsConecta;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('     ASSIGNAR CENTRAL UNA CONNEXIO      ');
    DBMS_OUTPUT.PUT_LINE('----------------------------------------');
    DBMS_OUTPUT.PUT_LINE('     Data Alta connexio: ' ||p_dataAltaConecta||
    ', Codi Central Produccio: ' ||p_conectaCentralProduccio||
    ', Codi Central Distribucio: ' ||p_conectaCentralDistribucio||
    ', Observacions Connexio: ' ||p_observacionsConecta);
    c_sortidalog := 's_rsp';
    
-- mirem si les dades no son nules    
if p_dataAltaConecta IS NULL then
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL UNA CONNEXIO:  ');
  s_rsp := 'Falta especificar Data Alta. ';
  DBMS_OUTPUT.PUT_LINE(s_rsp);           
  RAISE e_conceta_centrals;
END IF;
if p_conectaCentralProduccio IS NULL then
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL CONEXIO:  ');
    s_rsp := 'Falta el codi de la central de produccio';
    DBMS_OUTPUT.PUT_LINE(s_rsp);           
    RAISE e_conceta_centrals;
END IF;
if p_conectaCentralDistribucio IS NULL then
   DBMS_OUTPUT.ENABLE;
   DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL CONEXIO:  ');
   s_rsp := 'Falta el codi de la central de distribucio';
   DBMS_OUTPUT.PUT_LINE(s_rsp);           
   RAISE e_conceta_centrals;
END IF;
-- mirem si hi ha mes d'un connexio de central de distribucio amb una de produccio
SELECT DISTINCT COUNT(p_conectaCentralProduccio) INTO n_connexio
FROM LINEA_CONECTA_CENTRAL
WHERE LINEA_CONECTA_CENTRAL.CONNECTACDISTRI=p_conectaCentralDistribucio;

-- si hi ha mes de dues llavors no pot fer-se la conexio en cas
-- contrari continua en sequencia.
IF n_connexio>2 THEN
 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL UNA CONNEXIO:  ');
 s_rsp := 'La central de distribucio esta connectada amb dues Centrals de produccio,
 no pot connectar-se amb aquesta central de produccio. ';
 DBMS_OUTPUT.PUT_LINE(s_rsp);           
 RAISE e_conceta_centrals;
ELSE
n_conectarCentral:=1;
END IF;
-- EXAMINEN la central de produccio.
-- n_produccio si hi ha 1 llavors exiteix la central de produccio
-- sino no es central de produccio i emet excepcio.
SELECT DISTINCT COUNT (CENTRAL.ESTATCENTRAL) INTO n_produccio
FROM CENTRAL, CLASSE_CENTRAL, ESTAT
WHERE CENTRAL.IDCLASSECENTRAL=1
AND CLASSE_CENTRAL.IDCLASSE=CENTRAL.ESTATCENTRAL
AND CENTRAL.ESTATCENTRAL=ESTAT.IDESTAT
AND CENTRAL.IDTIPOCENTRAL<>6
AND CENTRAL.IDCENTRAL=p_conectaCentralProduccio;
-- si n_produccio=1 llavors a n_controlEstatPro hi ha 1=ALTA
-- o 2=Baixa en cas contrari no es una central de produccio o 
-- b no existeix
IF n_produccio=1 THEN
SELECT DISTINCT CENTRAL.ESTATCENTRAL INTO n_controlEstatPro
FROM CENTRAL, CLASSE_CENTRAL, ESTAT
WHERE CENTRAL.IDCLASSECENTRAL=1
AND CLASSE_CENTRAL.IDCLASSE=CENTRAL.ESTATCENTRAL
AND CENTRAL.ESTATCENTRAL=ESTAT.IDESTAT;
ELSE
 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL UNA CONNEXIO:  ');
 s_rsp := 'La central de produccio no exiteix a la BDD. ';
 DBMS_OUTPUT.PUT_LINE(s_rsp);           
 RAISE e_conceta_centrals;
END IF;
-- EXAMINEN la central de distribucio.
-- n_distribucio si hi ha 1 llavors exiteix la central de distribucio
-- sino no es central de distribucio i emet excepcio.
SELECT DISTINCT COUNT (CENTRAL.ESTATCENTRAL) INTO n_distribucio
FROM CENTRAL, CLASSE_CENTRAL, ESTAT
WHERE CENTRAL.IDCLASSECENTRAL=2
AND CLASSE_CENTRAL.IDCLASSE=CENTRAL.ESTATCENTRAL
AND CENTRAL.ESTATCENTRAL=ESTAT.IDESTAT
AND CENTRAL.IDTIPOCENTRAL=6
AND CENTRAL.IDCENTRAL=p_conectaCentralDistribucio; 
IF n_distribucio=1 THEN
SELECT DISTINCT CENTRAL.ESTATCENTRAL INTO n_controlEstatDis
FROM CENTRAL, CLASSE_CENTRAL, ESTAT
WHERE CENTRAL.IDCLASSECENTRAL=2
AND CLASSE_CENTRAL.IDCLASSE=CENTRAL.ESTATCENTRAL
AND CENTRAL.ESTATCENTRAL=ESTAT.IDESTAT
AND CENTRAL.IDTIPOCENTRAL=6
AND CENTRAL.IDCENTRAL=p_conectaCentralDistribucio;
ELSE 
 DBMS_OUTPUT.ENABLE;
 DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL UNA CONNEXIO:  ');
 s_rsp := 'La central de distribucio no exiteix a la BDD. ';
 DBMS_OUTPUT.PUT_LINE(s_rsp);           
 RAISE e_conceta_centrals;
END IF;

IF n_conectarCentral>2 AND n_distribucio=0 AND n_produccio=0 THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL UNA CONNEXIO:  ');
    s_rsp := 'No pot rfer-se la conexio. ';
    DBMS_OUTPUT.PUT_LINE(s_rsp);           
    RAISE e_conceta_centrals;
ELSE

 SELECT COUNT(*) INTO n_registres
 FROM LINEA_CONECTA_CENTRAL
 WHERE LINEA_CONECTA_CENTRAL.CONNECTACPRODU=p_conectaCentralProduccio
 AND LINEA_CONECTA_CENTRAL.CONNECTACDISTRI=p_conectaCentralDistribucio
 AND LINEA_CONECTA_CENTRAL.DATAALTAC=p_dataAltaConecta;
END IF;

IF n_registres=0 THEN
n_estatConecta:=1;
-- El donem d'alta la Linea de conexio entre les centrals de produccio i distribucio         
 INSERT INTO LINEA_CONECTA_CENTRAL(
                                  DATAALTAC,
                                  IDESTATC,
                                  CONNECTACPRODU,
                                  CONNECTACDISTRI,
                                  OBSERVACIOC) 
            VALUES(p_dataAltaConecta,
                  n_estatConecta,
                  p_conectaCentralProduccio,
                  p_conectaCentralDistribucio,
                  p_observacionsConecta);
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL UNA CONNEXIO:
  La Central de Produccio: '||p_conectaCentralProduccio||
  ' amb la Central de Distribucio: '||p_conectaCentralDistribucio||
  ' Connectada: '||n_controlEstatPro||
  ' ha estat inserida i conectada satisfactiament.');
  DBMS_OUTPUT.PUT_LINE(' ********** FIN DE LES OPERACIONS **********');
  --Gravem en la taula log-----------------------------------------------------
  s_rsp :='Ok La Central de Produccio: '||p_conectaCentralProduccio||
  ' amb la Central de Distribucio: '||p_conectaCentralDistribucio||
  ' Connectada: '||n_controlEstatPro||
  ' ha estat inserida i conectada satisfactiament.';
  pkg_general.gravar_log_procedure(c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  DBMS_OUTPUT.PUT_LINE(s_rsp);
ELSE
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('ASSIGNAR CENTRAL UNA CONNEXIO: ');
  s_rsp := 'Linea duplicada';
  DBMS_OUTPUT.PUT_LINE(s_rsp);
  RAISE e_conceta_centrals;
END IF;
COMMIT;     
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' '); 
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  ROLLBACK;     
    
END PRC_CONECTA_CENTRALS;
/******************************************************************************
NOM: PRC_MODIFICA_CONNEXIO
DESCRIPCIO: Procediment per modificar una connexio.
******************************************************************************/

PROCEDURE PRC_MODIFICA_CONNEXIO(
    p_idConectaCentral in LINEA_CONECTA_CENTRAL.IDCONECTA%Type,
    p_estatConecta in LINEA_CONECTA_CENTRAL.IDESTATC%Type,
    p_dataModificaConectaCentral in LINEA_CONECTA_CENTRAL.DATAMODIFICACIOC%Type,    
    p_conectaCentralProduccio in LINEA_CONECTA_CENTRAL.CONNECTACPRODU%Type,
    p_conectaCentralDistribucio in LINEA_CONECTA_CENTRAL.CONNECTACDISTRI%Type,
    p_observacionsConecta in LINEA_CONECTA_CENTRAL.OBSERVACIOC%Type,
    s_rsp out NOCOPY VARCHAR)
AS
BEGIN
    c_procesLog := ' PRC_MODIFICA_CONNEXIO';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :=' CCodi Linea conexio centrals: '||p_idConectaCentral||
    ', Data Modificacio: ' ||p_dataModificaConectaCentral||
    ', Codi Central Produccio: ' ||p_conectaCentralProduccio||
    ', Codi Central Distribucio: ' ||p_conectaCentralDistribucio||
    ', Codi Estat Linea: ' ||p_estatConecta||
    ', Observacions Connexio: ' ||p_observacionsConecta;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE(' MODIFICAR LA CONEXIO DE LES CENTRALS ');
    DBMS_OUTPUT.PUT_LINE('------------------------------------- ');
    DBMS_OUTPUT.PUT_LINE('
      Codi Linea conexio centrals: '||p_idConectaCentral||
    ', Data Modificacio: ' ||p_dataModificaConectaCentral||
    ', Codi Central Produccio: ' ||p_conectaCentralProduccio||
    ', Codi Central Distribucio: ' ||p_conectaCentralDistribucio||
    ', Codi Estat Linea: ' ||p_estatConecta||
    ', Observacions Connexio: ' ||p_observacionsConecta);
    c_sortidalog := 's_rsp';
    
     if  p_dataModificaConectaCentral IS NULL then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('MODIFICAR LA CONEXIO DE LES CENTRALS:  ');
            s_rsp := 'Falta especificar Data de la modificacio ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);           
          RAISE e_conceta_centrals;
     END IF;
     if p_conectaCentralProduccio IS NULL then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('MODIFICAR LA CONEXIO DE LES CENTRALS::  ');
            s_rsp := 'Falta el codi de la central de produccio.';
            DBMS_OUTPUT.PUT_LINE(s_rsp);           
          RAISE e_conceta_centrals;
     END IF;
      if p_conectaCentralDistribucio IS NULL then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('MODIFICAR LA CONEXIO DE LES CENTRALS::  ');
            s_rsp := 'Falta el codi de la central de distribucio. ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);           
          RAISE e_conceta_centrals;
     END IF;
     -- obting el lietral d'estat
     SELECT ESTAT.DESCRIPCIOESTAT INTO n_descEstatConecta
     FROM ESTAT
     WHERE ESTAT.IDESTAT=p_estatConecta;
     -- OBTING EL CODI ESTAT DE LA LINEA CONECTADA DE CENTRALS
     SELECT  DISTINCT LINEA_CONECTA_CENTRAL.IDESTATC INTO n_estatConecta
     FROM LINEA_CONECTA_CENTRAL
     WHERE LINEA_CONECTA_CENTRAL.IDESTATC=p_estatConecta;  
    -- MIRO SI LES DADES SON CORRECTES 
    IF n_estatConecta>2 OR n_estatConecta<1 THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('MODIFICAR LA CONEXIO DE LES CENTRALS:  ');
    s_rsp := 'El codi estat connexio no es correcte, te que ser 1=alta o 2=baixa. ';
    DBMS_OUTPUT.PUT_LINE(s_rsp);           
    RAISE e_conceta_centrals;
    END IF;
--miren si exiteixen les centrals en la BDD en la conectivitat 
--CERCA CENTRAL PRODUCCIO RECUPEREM LA LINEA DE CONEXIO
    SELECT DISTINCT COUNT(LINEA_CONECTA_CENTRAL.IDCONECTA) INTO n_produccio
    FROM LINEA_CONECTA_CENTRAL
    WHERE LINEA_CONECTA_CENTRAL.CONNECTACPRODU=p_conectaCentralProduccio;
    
    SELECT DISTINCT LINEA_CONECTA_CENTRAL.IDCONECTA INTO n_lineaProduccio
    FROM LINEA_CONECTA_CENTRAL
    WHERE LINEA_CONECTA_CENTRAL.CONNECTACPRODU=p_conectaCentralProduccio;
If n_produccio=0  then
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('MODIFICAR LA CONEXIO DE LES CENTRALS: '); 
      s_rsp := 'No hi linea cenectada no existent a la BBDD';
      DBMS_OUTPUT.PUT_LINE(s_rsp);
      RAISE e_conceta_centrals;
    END IF;    
  -- n_linea hi ha la linea ce conexio   
  s_sql := 'UPDATE LINEA_CONECTA_CENTRAL SET ';
  -- Construirem la sentencia UPDATE segons si hi ha valor en els paràmetres-

    -- Modifiquem Data Estat Linea
    IF p_estatConecta IS NOT NULL THEN
    s_sql := s_sql || 'IDESTAT=''' ||p_estatConecta || ''',';
    END IF;
    -- MODIFICO LA DATA
    IF p_dataModificaConectaCentral IS NOT NULL THEN
    -- Modifiquem data Linea
    s_sql := s_sql || 'DATAMODIFICACIOC=''' ||p_dataModificaConectaCentral|| ''',';
    END IF;
    IF p_conectaCentralProduccio IS NOT NULL THEN
    -- Modifiquem central produccio
      s_sql := s_sql || 'CONNECTACPRODU=''' ||p_conectaCentralProduccio|| ''',';
    END IF; 
    IF p_conectaCentralDistribucio IS NOT NULL THEN
     -- Modifiquem central de distribucio
    s_sql := s_sql || 'CONNECTACDISTRI=''' ||p_conectaCentralDistribucio|| ''',';
    END IF; 
    IF p_observacionsConecta IS NOT NULL THEN
    -- Modifiquem Observacions Inspeccio
    s_sql := s_sql || 'OBSERVACIOC=''' ||p_observacionsConecta || ''',';
    END IF; 
  -- Eliminem la coma final de la sentencia SQL--------------------------
    s_sql := SUBSTR (s_sql, 1, LENGTH (s_sql) - 1);
    -- Afegim a la sentencia la condiciÃ³ del WHERE------------------------
    s_sql := s_sql || ' WHERE IDCONECTA=''' ||n_lineaProduccio|| '''';
                  
EXECUTE IMMEDIATE s_sql;

  IF SQL%ROWCOUNT = 0 THEN
  --L'error serà que Tipo Linea ja el tenim en la taula i no admet duplicats--
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('MODIFICAR LA CONEXIO DE LES CENTRALS: ');                  
  s_rsp := 'Actualitzacio no realitzada';
  DBMS_OUTPUT.PUT_LINE(s_rsp);                  
  RAISE e_conceta_centrals;
  ELSE
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('MODIFICACIO de CONEXIO feta en
  Codi Linea connexio Centrals: '||p_idConectaCentral||
  ' amb Data de Modificacio: '||p_dataModificaConectaCentral||
  ' Estat modificat: '||n_descEstatConecta||
  ' Central Produccio: '||p_conectaCentralProduccio||
  ' Central Distribucio:'||p_conectaCentralDistribucio||
  ' Observacions: '||p_observacionsConecta);
  DBMS_OUTPUT.PUT_LINE('********** FI DE LES OPERACIONS **********');
  s_rsp := 'OK: MODIFICACIO de CONEXIO feta en
  Codi Linea connexio Centrals: '||p_idConectaCentral||
  ' amb Data de Modificacio: '||p_dataModificaConectaCentral||
  ' Estat modificat: '||n_descEstatConecta||
  ' Central Produccio: '||p_conectaCentralProduccio||
  ' Central Distribucio:'||p_conectaCentralDistribucio||
  ' Observacions: '||p_observacionsConecta;
  pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
END IF;
COMMIT;
  EXCEPTION
   WHEN OTHERS THEN
    IF s_rsp IS NULL THEN
-- L'error no ha estat controlat per codi
      s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
    ELSE
-- L'error si ha estat controlat per codi
     s_rsp := 'Error: ' || s_rsp;
    END IF;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('  ');    
    DBMS_OUTPUT.put_line(s_rsp);
    pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  ROLLBACK;    
      
END PRC_MODIFICA_CONNEXIO;


PROCEDURE PRC_CONSULTAR_CONEXIO_CENT(
  p_idConectaCentral in LINEA_CONECTA_CENTRAL.IDCONECTA%Type,
  s_rsp out NOCOPY VARCHAR2)
  AS
  CURSOR C_CONEXIONS_CENT IS
  SELECT LINEA_CONECTA_CENTRAL.IDCONECTA,
  LINEA_CONECTA_CENTRAL.DATAALTAC,
  ESTAT.DESCRIPCIOESTAT,
  LINEA_CONECTA_CENTRAL.DATAMODIFICACIOC,
  LINEA_CONECTA_CENTRAL.CONNECTACPRODU,
  LINEA_CONECTA_CENTRAL.CONNECTACDISTRI,
  LINEA_CONECTA_CENTRAL.OBSERVACIOC
  FROM LINEA_CONECTA_CENTRAL,ESTAT
  WHERE LINEA_CONECTA_CENTRAL.IDCONECTA=p_idConectaCentral
  AND LINEA_CONECTA_CENTRAL.IDESTATC=ESTAT.IDESTAT;
BEGIN
   c_procesLog := 'CONSULTAR_CONEXIO_CENT';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :=' Codi Linea: '||p_idConectaCentral;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('     CONSULTA UNA CONEXIO DE CENTRALS     ');
    DBMS_OUTPUT.PUT_LINE('------------------------------------------');
    DBMS_OUTPUT.PUT_LINE(' Codi Linea: '||p_idConectaCentral);
    c_sortidalog := 's_rsp'; 
    
    SELECT COUNT(*) INTO n_registres
    FROM LINEA_CONECTA_CENTRAL
    WHERE LINEA_CONECTA_CENTRAL.IDCONECTA=p_idConectaCentral;
    
    IF n_registres=0 THEN
     DBMS_OUTPUT.ENABLE;
     DBMS_OUTPUT.PUT_LINE(' CONSULTA UNA CONEXIO DE CENTRALS: '); 
     s_rsp := 'No hi linea cenectada no existent a la BBDD';
      DBMS_OUTPUT.PUT_LINE(s_rsp);
      RAISE e_conceta_centrals;
    END IF;
OPEN C_CONEXIONS_CENT;
FETCH C_CONEXIONS_CENT INTO
n_idConectaCentral,
n_dataAltaConecta,
n_descEstatConecta,
n_dataModificacioConecta,
n_conectaCentralProduccio,
n_conectaCentralDistribucio,
n_observacions;
WHILE C_CONEXIONS_CENT%FOUND LOOP
DBMS_OUTPUT.ENABLE;
DBMS_OUTPUT.PUT_LINE(
 '   Codi linea connexio Central:  '
 ||n_idConectaCentral||
 ' Data alta linea connexio:  '
 ||n_dataAltaConecta||
 ' Estat:  '
 ||n_descEstatConecta||
 ' Data Modificacio: '
 ||n_dataModificacioConecta||
 ' Codi Central Produccio: '
 ||n_conectaCentralProduccio||
 ' Codi Central Distribucio: '
 ||n_conectaCentralDistribucio||
  ' Observacions: '
 ||n_observacions);
  s_rsp := 'OK  CONSULTA UNA CONEXIO DE CENTRALS
   Codi linea connexio Central:  '
 ||n_idConectaCentral||
 ' Data alta linea connexio:  '
 ||n_dataAltaConecta||
 ' Estat:  '
 ||n_descEstatConecta||
 ' Data Modificacio: '
 ||n_dataModificacioConecta||
 ' Codi Central Produccio: '
 ||n_conectaCentralProduccio||
 ' Codi Central Distribucio: '
 ||n_conectaCentralDistribucio||
  ' Observacions: '
 ||n_observacions;
FETCH C_CONEXIONS_CENT INTO
n_idConectaCentral,
n_dataAltaConecta,
n_descEstatConecta,
n_dataModificacioConecta,
n_conectaCentralProduccio,
n_conectaCentralDistribucio,
n_observacions;
pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  
  END LOOP;
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('Total connexio de centrals: '||n_registres);
  DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');

CLOSE C_CONEXIONS_CENT;
COMMIT;     
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('  '); 
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  ROLLBACK;   
END PRC_CONSULTAR_CONEXIO_CENT; 

PROCEDURE PRC_CONSULTAR_CONEXIONS_CENT(
   s_rsp out NOCOPY VARCHAR2)
AS
  CURSOR C_CONEXIO_CENT IS
  SELECT LINEA_CONECTA_CENTRAL.IDCONECTA,
  LINEA_CONECTA_CENTRAL.DATAALTAC,
  ESTAT.DESCRIPCIOESTAT,
  LINEA_CONECTA_CENTRAL.DATAMODIFICACIOC,
  LINEA_CONECTA_CENTRAL.CONNECTACPRODU,
  LINEA_CONECTA_CENTRAL.CONNECTACDISTRI,
  LINEA_CONECTA_CENTRAL.OBSERVACIOC
  FROM LINEA_CONECTA_CENTRAL,ESTAT
  WHERE LINEA_CONECTA_CENTRAL.IDCONECTA=LINEA_CONECTA_CENTRAL.IDCONECTA
  AND LINEA_CONECTA_CENTRAL.IDESTATC=ESTAT.IDESTAT;
BEGIN
   c_procesLog := 'PRC_CONSULTAR_CONEXIONS_CENT';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='CONSULTA CONNEXIOS DE CENTRALS  ';
    c_sortidalog := 's_rsp'; 
    
    SELECT COUNT(*) INTO n_registres
    FROM LINEA_CONECTA_CENTRAL
    WHERE LINEA_CONECTA_CENTRAL.IDCONECTA=LINEA_CONECTA_CENTRAL.IDCONECTA;
    
    IF n_registres=0 THEN
     DBMS_OUTPUT.ENABLE;
     DBMS_OUTPUT.PUT_LINE(' CONSULTA CONNEXIOS DE CENTRALS: '); 
     s_rsp := 'No hi linea cenectada no existent a la BBDD';
      DBMS_OUTPUT.PUT_LINE(s_rsp);
      RAISE e_conceta_centrals;
    END IF;
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('     CONSULTA CONNEXIOS DE CENTRALS       ');
    DBMS_OUTPUT.PUT_LINE('------------------------------------------');   
   
OPEN C_CONEXIO_CENT;
FETCH C_CONEXIO_CENT INTO
n_idConectaCentral,
n_dataAltaConecta,
n_descEstatConecta,
n_dataModificacioConecta,
n_conectaCentralProduccio,
n_conectaCentralDistribucio,
n_observacions;
WHILE C_CONEXIO_CENT%FOUND LOOP
DBMS_OUTPUT.ENABLE;
DBMS_OUTPUT.PUT_LINE(
 '   Codi linea connexio Central:  '
 ||n_idConectaCentral||
 ' Data alta linea connexio:  '
 ||n_dataAltaConecta||
 ' Estat:  '
 ||n_descEstatConecta||
 ' Data Modificacio: '
 ||n_dataModificacioConecta||
 ' Codi Central Produccio: '
 ||n_conectaCentralProduccio||
 ' Codi Central Distribucio: '
 ||n_conectaCentralDistribucio||
  ' Observacions: '
 ||n_observacions);
  s_rsp := 'OK  CONSULTA UNA CONEXIO DE CENTRALS
   Codi linea connexio Central:  '
 ||n_idConectaCentral||
 ' Data alta linea connexio:  '
 ||n_dataAltaConecta||
 ' Estat:  '
 ||n_descEstatConecta||
 ' Data Modificacio: '
 ||n_dataModificacioConecta||
 ' Codi Central Produccio: '
 ||n_conectaCentralProduccio||
 ' Codi Central Distribucio: '
 ||n_conectaCentralDistribucio||
  ' Observacions: '
 ||n_observacions;
FETCH C_CONEXIO_CENT INTO
n_idConectaCentral,
n_dataAltaConecta,
n_descEstatConecta,
n_dataModificacioConecta,
n_conectaCentralProduccio,
n_conectaCentralDistribucio,
n_observacions;
pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  
  END LOOP;
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('Total connexio de centrals: '||n_registres);
  DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');

CLOSE C_CONEXIO_CENT;
COMMIT;     
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('  '); 
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  ROLLBACK;      
   
   
   
  
END PRC_CONSULTAR_CONEXIONS_CENT;   

END "GESTION_CONECTA_CENTRALS";
