CREATE OR REPLACE
PACKAGE BODY          "GESTION_LINEA_TIPUS" AS
  n_registres      NUMBER;
  s_sql           VARCHAR2 (2000);
  n_NUM_ERR 	  NUMBER(10);
 
  c_procesLog	  LOG_TFC.procesLog%TYPE;	
  c_dataHoraLog    LOG_TFC.dataHoraLog%TYPE;
  c_entradaLog     LOG_TFC.entradaLog%TYPE;	
  c_sortidaLog     LOG_TFC.sortidaLog%TYPE;
  s_rsp	 LOG_TFC.RSPLOG%TYPE; 
  
  n_estatLinea NUMBER;
  n_estatTipoLinea LINEA_TIPUS.IDESTATTLINEA%TYPE;
  n_dataEstatTipoLinea   LINEA_TIPUS.DATAESTATTLINEA%Type;
  n_consumMaximTipoLinea   LINEA_TIPUS.CONSUMMAXIMTLINEA%TYPE;
  n_observacionTipoLinea  LINEA_TIPUS.OBSERVACIOTLINEA%TYPE;
  n_idTipoLinea  LINEA_TIPUS.IDTLINEA%Type;
  n_estat ESTAT.DESCRIPCIOESTAT%TYPE;
  n_idEstat LINEA_TIPUS.IDESTATTLINEA%TYPE;
  
  sortida VARCHAR2(1000):='';
  e_tipus_linea  EXCEPTION;
--------------------------------------------------------------
/******************************************************************************
Autor: Eduard Monzonis Hierro                                   UOC
18/05/2012                                             TFC: CONTROL ENERGIA.
                  POCEDIMENT ALTA LINEA TIPUS
DESCRIPCIO:
La funcionalitat es de guardar els tipus de lineas on cada una d'elles tolera
una quantitat maxima de fluxe energeric.
Te dependencies amb LINEAS CONECTAR que hereda les dades per controlar
el nivell de sobrecarrega de les lineas.
******************************************************************************/
PROCEDURE PRC_ALTA_LINEA_TIPUS(
    p_dataEstatTipoLinea in LINEA_TIPUS.DATAESTATTLINEA%Type,
    p_consumMaximTipoLinea in LINEA_TIPUS.CONSUMMAXIMTLINEA%Type,
    p_observacionTipoLinea in LINEA_TIPUS.OBSERVACIOTLINEA%Type,
    s_rsp out NOCOPY VARCHAR)
    AS
    
    BEGIN
    c_procesLog := 'PRC_LINEA_ ALTA_TIPUS';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='Data Estat Tipus Linea: ' ||p_dataEstatTipoLinea||
    ', Cosum Maxim Tolerat Linea Tipus: ' ||p_consumMaximTipoLinea||
    ', Observacions Tipus Linea: ' ||p_observacionTipoLinea;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('     ALTA TIPUS DE LINEA     ');
    DBMS_OUTPUT.PUT_LINE('_____________________________');
    DBMS_OUTPUT.PUT_LINE('Data Estat Tipus Linea: ' ||p_dataEstatTipoLinea||
    ', Cosum Maxim Tolerat Linea Tipus: ' ||p_consumMaximTipoLinea||
    ', Observacions Tipus Linea: ' ||p_observacionTipoLinea);
    c_sortidalog := 's_rsp';   
        
    -- comprovacio de dades entrades per donar d'alta
      n_estatLinea:=1;
    If (p_dataEstatTipoLinea IS NULL) then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('     ALTA TIPUS DE LINEA     ');
            DBMS_OUTPUT.PUT_LINE('_____________________________');   
            s_rsp := 'Falta especificar data Estat Tipus Linea ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);               
          RAISE e_tipus_linea;
     END IF;
      If (p_consumMaximTipoLinea IS NULL) then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('     ALTA TIPUS DE LINEA     ');
            DBMS_OUTPUT.PUT_LINE('_____________________________');        
            s_rsp := 'Falta especificar el Cosum Maxim tolerable Tipus Linea ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);            
          RAISE e_tipus_linea;
     END IF;
    If (p_consumMaximTipoLinea<0 OR  p_consumMaximTipoLinea=0) then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('     ALTA TIPUS DE LINEA     ');
            DBMS_OUTPUT.PUT_LINE('_____________________________');         
            s_rsp := 'Falta especificar el Cosum Maxim tolerable Tipus Linea no pot ser 0 menor de 0 ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);            
          RAISE e_tipus_linea;
     END IF;
     -- Comprovem si existeix el estat  donar d'alta
         SELECT COUNT (*)      INTO n_registres 
            FROM LINEA_TIPUS
            WHERE IDESTATTLINEA =  n_estatLinea
            AND DATAESTATTLINEA=p_dataEstatTipoLinea
            AND LINEA_TIPUS.IDTLINEA= LINEA_TIPUS.IDTLINEA
            AND CONSUMMAXIMTLINEA=p_consumMaximTipoLinea;
            
      If n_registres=0 then
      n_estatLinea:=1;
          -- El donem d'alta Tipus Linea          
      INSERT INTO LINEA_TIPUS(IDESTATTLINEA,
                              DATAESTATTLINEA,
                              CONSUMMAXIMTLINEA,
                              OBSERVACIOTLINEA) 
            VALUES(n_estatLinea,
                  p_dataEstatTipoLinea,
                  p_consumMaximTipoLinea,
                  p_observacionTipoLinea);
            --Gravem en la taula log-----------------------------------------------------            
            
            
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('Insertada el tipus de linea:  en la data: '||p_dataEstatTipoLinea||
            ' Consum maxim tolerable de:  '||p_consumMaximTipoLinea||
            ' Observacions: '||p_observacionTipoLinea);
            DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
            s_rsp :='Ok: Insertada el tipus de linea:  en la data: '||p_dataEstatTipoLinea||
            ' Consum maxim tolerable de:  '||p_consumMaximTipoLinea||
            ' Observacions: '||p_observacionTipoLinea;
            pkg_general.gravar_log_procedure(c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
            DBMS_OUTPUT.PUT_LINE(s_rsp);
          ELSE
           DBMS_OUTPUT.ENABLE;
           DBMS_OUTPUT.PUT_LINE('     ALTA TIPUS DE LINEA     ');
           DBMS_OUTPUT.PUT_LINE('_____________________________');       
           s_rsp := 'DADES duplicades';
           DBMS_OUTPUT.PUT_LINE(s_rsp);
          RAISE e_tipus_linea;
      END IF;
   COMMIT;
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' '); 
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;
END PRC_ALTA_LINEA_TIPUS;
/*******************************************************************************
Autor: Eduard Monzonis Hierro                                   UOC
18/05/2012                                             TFC: CONTROL ENERGIA.
               MODIFICAR  DADES DE LA LINEA TIPUS
DESCRIPCIO:
Procediment per modificar les dades del tipus de linea.
*******************************************************************************/

PROCEDURE PRC_MODIFICAR_LINEA_TIPUS(
    p_idTipoLinea in LINEA_TIPUS.IDTLINEA%Type,
    p_estatTipoLinea in LINEA_TIPUS.IDESTATTLINEA%Type,
    p_dataEstatTipoLinea in LINEA_TIPUS.DATAESTATTLINEA%Type,
    p_consumMaximTipoLinea in LINEA_TIPUS.CONSUMMAXIMTLINEA%Type,
    p_observacionTipoLinea in LINEA_TIPUS.OBSERVACIOTLINEA%Type,
    s_rsp out NOCOPY VARCHAR2)
    AS
 
    BEGIN
    c_procesLog := 'PRC_MODIFICAR_LINEA_TIPUS';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='Id Tipus Linea: ' ||p_idTipoLinea||
    --', Estat Tipus Linea: ' || p_estatTipoLinea||
    ', Data Estat Tipus Linea: ' ||p_dataEstatTipoLinea||
    ', Cosum Maxim Tolerat Linea Tipus: ' ||p_consumMaximTipoLinea||
    ', Observacions Tipus Linea: ' ||p_observacionTipoLinea;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('    MODIFICAR LINEA TIPUS     ');
    DBMS_OUTPUT.PUT_LINE('_____________________________');
    DBMS_OUTPUT.PUT_LINE('Id Tipus Linea: ' ||p_idTipoLinea||
    --', Estat Tipus Linea: ' || p_estatTipoLinea||
    ', Data Estat Tipus Linea: ' ||p_dataEstatTipoLinea||
    ', Cosum Maxim Tolerat Linea Tipus: ' ||p_consumMaximTipoLinea||
    ', Observacions Tipus Linea: ' ||p_observacionTipoLinea);
    c_sortidalog := 's_rsp'; 
-- comprovacio de dades    
     IF p_idTipoLinea IS NULL THEN
        DBMS_OUTPUT.ENABLE;
        DBMS_OUTPUT.PUT_LINE('MODIFICAR LINEA TIPUS: ');     
       s_rsp := 'Falta especificar el codi Tipus Linea ';
       DBMS_OUTPUT.PUT_LINE(s_rsp);        
        RAISE e_tipus_linea;
        END IF;
    If (p_dataEstatTipoLinea IS NULL) then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('MODIFICAR LINEA TIPUS: ');    
            s_rsp := 'Falta especificar data Estat Tipus Linea ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);               
          RAISE e_tipus_linea;
        END IF;
      If (p_consumMaximTipoLinea IS NULL) then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('MODIFICAR LINEA TIPUS: ');        
            s_rsp := 'Falta especificar el Cosum Maxin tolerable Tipus Linea ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);            
          RAISE e_tipus_linea;
       END IF;
    If (p_consumMaximTipoLinea<0 OR  p_consumMaximTipoLinea=0) then
            DBMS_OUTPUT.ENABLE;
            DBMS_OUTPUT.PUT_LINE('MODIFICAR_LINEA_TIPUS ');            
            s_rsp := 'Falta especificar el Cosum Maxim tolerable Tipus Linea ';
            DBMS_OUTPUT.PUT_LINE(s_rsp);            
          RAISE e_tipus_linea;
     END IF;      
     -- recuperem el codi Tipus Linea, estat i data estat
         SELECT LINEA_TIPUS.IDTLINEA,LINEA_TIPUS.IDESTATTLINEA,ESTAT.DESCRIPCIOESTAT  
         INTO n_idTipoLinea,n_estatTipoLinea,n_estat
                 FROM LINEA_TIPUS,ESTAT
                 WHERE LINEA_TIPUS.IDTLINEA=1
                 AND ESTAT.IDESTAT=LINEA_TIPUS.IDESTATTLINEA;
                 
         
         SELECT COUNT (*)INTO n_registres 
            FROM LINEA_TIPUS
            WHERE LINEA_TIPUS.IDTLINEA=p_idTipoLinea;
            
              If n_registres=0 then
               DBMS_OUTPUT.ENABLE;
               DBMS_OUTPUT.PUT_LINE('MODIFICAR LINEA TIPUS: ');                 
               s_rsp := 'Tipus Linea no existent a la BBDD';
               DBMS_OUTPUT.PUT_LINE(s_rsp);
               RAISE e_tipus_linea;
              END IF;
    
      s_sql := 'UPDATE LINEA_TIPUS SET ';
     -- Construirem la sentencia UPDATE segons si hi ha valor en els paràmetres-             
     IF p_dataEstatTipoLinea IS NOT NULL THEN
      -- Modifiquem Data Estat Tipo Linea
      s_sql := s_sql || ' DATAESTATTLINEA=''' ||p_dataEstatTipoLinea|| ''',';
     END IF;
     IF p_consumMaximTipoLinea IS NOT NULL THEN
      -- Modifiquem el Consum Maxim Tipo Linea
      s_sql := s_sql || 'CONSUMMAXIMTLINEA=''' ||p_consumMaximTipoLinea|| ''',';
    END IF;                   
    IF p_observacionTipoLinea IS NOT NULL THEN
    -- Modifiquem Observacions Tipo Linea
    s_sql := s_sql || 'OBSERVACIOTLINEA=''' ||p_observacionTipoLinea|| ''',';
    END IF; 
 -- Eliminem la coma final de la sentencia SQL--------------------------
    s_sql := SUBSTR (s_sql, 1, LENGTH (s_sql) - 1);
-- Afegim a la sentencia la condiciÃ³ del WHERE------------------------
 s_sql := s_sql || ' WHERE IDTLINEA=''' ||n_idTipoLinea || '''';
    EXECUTE IMMEDIATE s_sql;
 IF SQL%ROWCOUNT = 0 THEN
--L'error serà que Tipo Linea ja el tenim en la taula i no admet duplicats--
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('MODIFICAR LINEA TIPUS: ');                  
    s_rsp := 'Actualitzacio no realitzada';
    DBMS_OUTPUT.PUT_LINE(s_rsp);                  
    RAISE e_tipus_linea;
  ELSE
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('MODIFICAR_LINEA_TIPUS '); 
    DBMS_OUTPUT.PUT_LINE('Actualitzacio de la linea: '||p_idTipoLinea||
    ' en data '||p_dataEstatTipoLinea||
    ' en un consum maxim tolerable de '||p_consumMaximTipoLinea||
    ' Observacions. '||p_observacionTipoLinea||' ha estat satisfactoria.');
    DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
    s_rsp := 'OK Actualitzacio de la linea: '||p_idTipoLinea||
    ' en data '||p_dataEstatTipoLinea||
    ' en un consum maxim tolerable de '||p_consumMaximTipoLinea||
    ' Observacions. '||p_observacionTipoLinea||' ha estat satisfactoria.';
    DBMS_OUTPUT.put_line ('OK Actualitzacio de la linea: '||p_idTipoLinea||
    ' en data '||p_dataEstatTipoLinea||
    ' en un consum maxim tolerable de '||p_consumMaximTipoLinea||
    ' Observacions. '||p_observacionTipoLinea||' ha estat satisfactoria.');
    pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  END IF;
COMMIT;
  EXCEPTION
    WHEN DUP_VAL_ON_INDEX THEN
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('MODIFICAR_LINEA_TIPUS ');    
      s_rsp := 'Error: Tipo Linea duplicada. No es poden fer les modificacions';
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;      
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || SQLCODE || SUBSTR(SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' '); 
      DBMS_OUTPUT.put_line (s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;    
END PRC_MODIFICAR_LINEA_TIPUS;
/*******************************************************************************
Autor: Eduard Monzonis Hierro                                   UOC
18/05/2012                                             TFC: CONTROL ENERGIA.
--  BAIXA LINEA
******************************************************************************/
PROCEDURE PRC_BAIXA_LINEA_TIPUS(
    p_idTipoLinea in LINEA_TIPUS.IDTLINEA%Type,
    p_estatTipoLinea in LINEA_TIPUS.IDESTATTLINEA%Type,
    p_dataEstatTipoLinea in LINEA_TIPUS.DATAESTATTLINEA%Type,
    p_observacionTipoLinea in LINEA_TIPUS.OBSERVACIOTLINEA%Type,
    s_rsp out NOCOPY VARCHAR2)
 AS
 
 BEGIN
    c_procesLog := 'PRC_BAIXA_LINEA_TIPUS';
    c_dataHoraLog := SYSDATE;
    c_entradaLog :='Id Tipus Linea: ' ||p_idTipoLinea||
    ' Data Estat Tipus Linea: ' ||p_dataEstatTipoLinea;
    DBMS_OUTPUT.PUT_LINE(' ');
    DBMS_OUTPUT.PUT_LINE('    BAIXA LINEA TIPUS     ');
    DBMS_OUTPUT.PUT_LINE('_____________________________');
    DBMS_OUTPUT.PUT_LINE('Codi Tipus Linea: ' ||p_idTipoLinea||
    ' Data Estat Tipus Linea: ' ||p_dataEstatTipoLinea);
    c_sortidalog := 's_rsp';    
   IF p_idTipoLinea IS NULL THEN
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('BAIXA LINEA TIPUS  : ');       
      s_rsp := 'Falta especificar el codi Tipo Linea ';
      DBMS_OUTPUT.PUT_LINE(s_rsp);           
      RAISE e_tipus_linea;
   END IF;
   IF p_dataEstatTipoLinea IS NULL THEN
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('BAIXA LINEA TIPUS  : ');       
      s_rsp := 'Falta especificar la data de la modificacio de estat de Tipus Linea ';
      DBMS_OUTPUT.PUT_LINE(s_rsp);           
      RAISE e_tipus_linea;
   END IF;   
--1er. Comprovem que existeixi Tipo Linea-------------------------------
   SELECT COUNT (*) INTO n_registres 
   FROM LINEA_TIPUS
   WHERE  LINEA_TIPUS.IDTLINEA=p_idTipoLinea;
 IF n_registres =0 THEN
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('BAIXA LINEA TIPUS  : '||p_idTipoLinea||
  ' ha de fer-se una alta de la linea tipus. ');       
  s_rsp := 'BAIXA LINEA TIPUS  : '||p_idTipoLinea||
  ' ha de fer-se una alta de la linea tipus. ';
  DBMS_OUTPUT.PUT_LINE(s_rsp);           
  RAISE e_tipus_linea;
 ELSE
 --RECUPEREM LA LINEA TIPUS
 SELECT LINEA_TIPUS.IDTLINEA,
 LINEA_TIPUS.DATAESTATTLINEA,
 LINEA_TIPUS.IDESTATTLINEA
 ESTAT.DESCRIPCIOESTAT,
 LINEA_TIPUS.CONSUMMAXIMTLINEA,
 LINEA_TIPUS.OBSERVACIOTLINEA
 INTO  n_idTipoLinea,n_dataEstatTipoLinea,n_idEstat,n_estatTipoLinea,n_consumMaximTipoLinea,n_observacionTipoLinea 
 FROM LINEA_TIPUS,ESTAT
 WHERE LINEA_TIPUS.IDTLINEA=p_idTipoLinea
 AND LINEA_TIPUS.IDESTATTLINEA= ESTAT.IDESTAT;
 n_estatLinea:=2;    
      s_sql := 'UPDATE LINEA_TIPUS SET ';
     -- Construirem la sentencia UPDATE segons si hi ha valor en els paràmetres-             
 IF (n_idEstat IS NOT NULL) AND (n_idEstat=1) THEN
-- Modifiquem Data Estat Tipo Linea
   s_sql := s_sql || 'IDESTATTLINEA=''' ||n_estatLinea|| ''',';
 END IF;
 IF p_dataEstatTipoLinea IS NOT NULL THEN
-- Modifiquem Data Estat Tipo Linea
  s_sql := s_sql || ' DATAESTATTLINEA=''' ||p_dataEstatTipoLinea|| ''',';
 END IF;
     
 -- Eliminem la coma final de la sentencia SQL--------------------------
    s_sql := SUBSTR (s_sql, 1, LENGTH (s_sql) - 1);
-- Afegim a la sentencia la condiciÃ³ del WHERE------------------------
 s_sql := s_sql || ' WHERE IDTLINEA=''' ||n_idTipoLinea || '''';
    EXECUTE IMMEDIATE s_sql; 
IF SQL%ROWCOUNT = 0 THEN
--L'error serà que Tipo Linea ja el tenim en la taula i no admet duplicats--
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('BAIXA DE LA LINEA TIPUS: ');                  
    s_rsp := 'Actualitzacio no realitzada';
    DBMS_OUTPUT.PUT_LINE(s_rsp);                  
    RAISE e_tipus_linea;
  ELSE
 SELECT LINEA_TIPUS.IDTLINEA,LINEA_TIPUS.DATAESTATTLINEA,
 LINEA_TIPUS.IDESTATTLINEA,ESTAT.DESCRIPCIOESTAT,
 LINEA_TIPUS.CONSUMMAXIMTLINEA,LINEA_TIPUS.OBSERVACIOTLINEA
 INTO  n_idTipoLinea,n_dataEstatTipoLinea,n_estat,n_dataEstatTipoLinea,
 n_consumMaximTipoLinea,n_observacionTipoLinea 
 FROM LINEA_TIPUS,ESTAT
 WHERE LINEA_TIPUS.IDTLINEA=p_idTipoLinea
 AND LINEA_TIPUS.IDESTATTLINEA= ESTAT.IDESTAT;
 
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('BAIXA LINEA TIPUS: '); 
    DBMS_OUTPUT.PUT_LINE('Actualitzacio de baixa de la linea: '||p_idTipoLinea||
    ' data de la baixa: '||n_dataEstatTipoLinea||
    ' estat: '||n_estat||
    '=Baixa amb consum maxim tolerable de '||n_consumMaximTipoLinea||
    ' Observacions. '||n_observacionTipoLinea||' ha estat satisfactoria.');
    DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
    s_rsp := 'OK Actualitzacio de la linea: '||p_idTipoLinea||
    ' en data '||n_dataEstatTipoLinea||
    ' en un consum maxim tolerable de '||n_consumMaximTipoLinea||
    ' Observacions. '||n_observacionTipoLinea||' ha estat satisfactoria.';
    DBMS_OUTPUT.put_line ('OK Actualitzacio de la linea: '||p_idTipoLinea||
    ' en data '||n_dataEstatTipoLinea||
    ' en un consum maxim tolerable de '||n_consumMaximTipoLinea||
    ' Observacions. '||n_observacionTipoLinea||' ha estat satisfactoria.');
    pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  END IF;
  END IF;
COMMIT;
 EXCEPTION
    WHEN DUP_VAL_ON_INDEX THEN
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE('BAIXA LINEA TIPUS: ');    
      s_rsp := 'Error: Tipo Linea duplicada. No es poden fer les modificacions';
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;      
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || SQLCODE || SUBSTR(SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         -----------------------------------------
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' '); 
      DBMS_OUTPUT.put_line (s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;    
    
END PRC_BAIXA_LINEA_TIPUS;
--
-- CONSULTA LINEA_TIPUS ESTAT ACTIVAS
PROCEDURE PRC_CONSULTAR_LINEA_ACTIVA(
  s_rsp out NOCOPY VARCHAR2)
AS
CURSOR C_LIENAS_TIPUS_ON IS
    SELECT DISTINCT LINEA_TIPUS.IDTLINEA AS CODI,
           LINEA_TIPUS.DATAESTATTLINEA AS FECHA,
           ESTAT.DESCRIPCIOESTAT AS ESTAT,
           LINEA_TIPUS.CONSUMMAXIMTLINEA AS COSUM_MAXIM_TOLERABLE,
          LINEA_TIPUS.OBSERVACIOTLINEA AS OBSERVACIONS
    FROM LINEA_TIPUS,ESTAT
    WHERE LINEA_TIPUS.IDTLINEA=
    LINEA_TIPUS.IDTLINEA
    AND LINEA_TIPUS.IDESTATTLINEA=1
    AND LINEA_TIPUS.IDESTATTLINEA=ESTAT.IDESTAT
    ORDER BY LINEA_TIPUS.IDTLINEA;

BEGIN
 c_procesLog := 'PRC_CONSULTAR_LINEA_ACTIVA';
 c_dataHoraLog := SYSDATE;
 c_entradaLog :='CONSULTA LINEAS ACTIVADES ';
 c_sortidalog := 's_rsp'; 
-- Comprovem que id Tipo Linea ESTIGUI EN ESTAT 1=Alta
   SELECT COUNT(LINEA_TIPUS.IDTLINEA) INTO n_idTipoLinea
     FROM LINEA_TIPUS
      WHERE LINEA_TIPUS.IDTLINEA=LINEA_TIPUS.IDTLINEA
      AND LINEA_TIPUS.IDESTATTLINEA=1;
   IF n_idTipoLinea=0 THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('CONSULTA TIPUS DE LINEAS ACTIVADES ');
    s_rsp := 'No hi han tipus de lineas que estiguin actives ';
    DBMS_OUTPUT.PUT_LINE(s_rsp);
    RAISE e_tipus_linea;
   END IF;
   
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('           CONSULTA TIPUS DE LINEAS ACTIVADES            ');
    DBMS_OUTPUT.PUT_LINE('---------------------------------------------------------');
  
  OPEN C_LIENAS_TIPUS_ON;
    FETCH C_LIENAS_TIPUS_ON INTO n_idTipoLinea,n_dataEstatTipoLinea,
    n_estat,n_consumMaximTipoLinea,
    n_observacionTipoLinea ;
  WHILE C_LIENAS_TIPUS_ON%FOUND LOOP
   DBMS_OUTPUT.ENABLE;
   DBMS_OUTPUT.PUT_LINE(
 ' Codi Tipus linea:  '
 ||n_idTipoLinea
 ||' Data Activacio: '
 ||n_dataEstatTipoLinea||
 ' Estat: '||n_estat||
 ' Consum maxim tolerable: '
 ||n_consumMaximTipoLinea||
 'Observacions: '||n_observacionTipoLinea);
  s_rsp := 'OK  CONSULTA DE LINEQAS TIPUS ACTIVADES
   Codi Tipus linea:  '
 ||n_idTipoLinea
 ||' Data Activacio: '
 ||n_dataEstatTipoLinea||
 ' Estat: '||n_estat||
 ' Consum maxim tolerable: '
 ||n_consumMaximTipoLinea||
 ' Observacions: '||n_observacionTipoLinea;
  FETCH C_LIENAS_TIPUS_ON INTO n_idTipoLinea,n_dataEstatTipoLinea,
    n_estat,n_consumMaximTipoLinea,
    n_observacionTipoLinea ;
  pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  
  END LOOP;
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('Total tipus lineas en estat ON: '||n_idTipoLinea);
  DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
CLOSE C_LIENAS_TIPUS_ON;
COMMIT;
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' ');
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;    
END PRC_CONSULTAR_LINEA_ACTIVA;

-- CONSULTA LINEA TIPUS ESTAT LINEA NO ACTIVA  
PROCEDURE PRC_CONSULTAR_LINEA_NO_ACTIVA(
  s_rsp out NOCOPY VARCHAR2)
AS
    CURSOR C_LIENAS_TIPUS_OFF IS
    SELECT DISTINCT LINEA_TIPUS.IDTLINEA AS CODI,
           LINEA_TIPUS.DATAESTATTLINEA AS FECHA,
           ESTAT.DESCRIPCIOESTAT AS ESTAT,
           LINEA_TIPUS.CONSUMMAXIMTLINEA AS COSUM_MAXIM_TOLERABLE,
          LINEA_TIPUS.OBSERVACIOTLINEA AS OBSERVACIONS
    FROM LINEA_TIPUS,ESTAT
    WHERE LINEA_TIPUS.IDTLINEA=LINEA_TIPUS.IDTLINEA
    AND LINEA_TIPUS.IDESTATTLINEA=2
    AND LINEA_TIPUS.IDESTATTLINEA=ESTAT.IDESTAT
    ORDER BY LINEA_TIPUS.IDTLINEA;

BEGIN
 c_procesLog := 'PRC_CONSULTAR_LINEA_NO_ACTIVA';
 c_dataHoraLog := SYSDATE;
 c_entradaLog :='CONSULTA TIPUS DE LINEAS DESACTIVADES ';
 c_sortidalog := 's_rsp'; 
-- Comprovem que id Tipo Linea ESTIGUI EN ESTAT 1=Alta
   SELECT COUNT(LINEA_TIPUS.IDTLINEA) INTO n_idTipoLinea
     FROM LINEA_TIPUS
      WHERE LINEA_TIPUS.IDTLINEA=LINEA_TIPUS.IDTLINEA
      AND LINEA_TIPUS.IDESTATTLINEA=2;
   IF n_idTipoLinea=0 THEN
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('CONSULTA TIPUS DE LINEAS DESACTIVADES ');
    s_rsp := 'No hi han tipus de lineas que estiguin desactives ';
    DBMS_OUTPUT.PUT_LINE(s_rsp);
    RAISE e_tipus_linea;
   END IF;
   
    DBMS_OUTPUT.ENABLE;
    DBMS_OUTPUT.PUT_LINE('           CONSULTA TIPUS DE LINEAS DESACTIVADES            ');
    DBMS_OUTPUT.PUT_LINE('------------------------------------------------------------');
  
  OPEN C_LIENAS_TIPUS_OFF;
    FETCH C_LIENAS_TIPUS_OFF INTO n_idTipoLinea,
    n_estat,n_dataEstatTipoLinea,n_consumMaximTipoLinea,
    n_observacionTipoLinea ;
  WHILE C_LIENAS_TIPUS_OFF%FOUND LOOP
   DBMS_OUTPUT.ENABLE;
   DBMS_OUTPUT.PUT_LINE(
 ' Codi Tipus linea:  '
 ||n_idTipoLinea
 ||' Data Desactivacio: '
 ||n_dataEstatTipoLinea||
 ' Estat: '||n_estat||
 ' Consum maxim tolerable: '
 ||n_consumMaximTipoLinea||
 'Observacions: '||n_observacionTipoLinea);
  s_rsp := 'OK  CONSULTA LINEAS TIPUS NO ACTIVADES
   Codi Tipus linea:  '
 ||n_idTipoLinea
 ||' Data Activacio: '
 ||n_dataEstatTipoLinea||
 ' Estat: '||n_estat||
 ' Consum maxim tolerable: '
 ||n_consumMaximTipoLinea||
 ' Observacions: '||n_observacionTipoLinea;
  FETCH C_LIENAS_TIPUS_OFF INTO n_idTipoLinea,n_dataEstatTipoLinea,
    n_estat,n_consumMaximTipoLinea,
    n_observacionTipoLinea ;
    pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
  
  END LOOP;
  DBMS_OUTPUT.ENABLE;
  DBMS_OUTPUT.PUT_LINE('Total tipus lineas en estat OF o BAIXA: '||n_idTipoLinea);
  DBMS_OUTPUT.PUT_LINE('****** FI DE LES OPERACIONS *******');
CLOSE C_LIENAS_TIPUS_OFF;
COMMIT;
EXCEPTION
   WHEN OTHERS THEN
      IF s_rsp IS NULL THEN
         -- L'error no ha estat controlat per codi
         s_rsp := 'Error: ' || SQLCODE || SUBSTR (SQLERRM, 1, 100);
      ELSE
         -- L'error si ha estat controlat per codi
         s_rsp := 'Error: ' || s_rsp;
      END IF;
      DBMS_OUTPUT.ENABLE;
      DBMS_OUTPUT.PUT_LINE(' ');
      DBMS_OUTPUT.put_line(s_rsp);
      pkg_general.gravar_log_procedure (c_procesLog, c_dataHoraLog, c_entradaLog, c_sortidaLog, s_rsp);
      ROLLBACK;    
END PRC_CONSULTAR_LINEA_NO_ACTIVA;
END "GESTION_LINEA_TIPUS";
